@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "lab" "3.5.0"
+(define-package "lab" "20250827.5"
   "An interface for GitLab."
   '((emacs       "27.1")
     (request     "0.3.2")
@@ -9,7 +9,7 @@
     (promise     "1.1")
     (async-await "1.1"))
   :url "https://github.com/isamert/lab.el"
-  :commit "547d9dd773dd3747c4345cf0b9111ac0ed8c14b4"
-  :revdesc "547d9dd773dd"
+  :commit "a29b3ccadeab31b6582fedd0e35e5bf46c96fc64"
+  :revdesc "a29b3ccadeab"
   :authors '(("Isa Mert Gurbuz" . "isamertgurbuz@gmail.com"))
   :maintainers '(("Isa Mert Gurbuz" . "isamertgurbuz@gmail.com")))
